/**
 *    @file  suite_libhttp.c
 *   @brief  Check testsuite for libhttp functions
 *  @author  François Cerbelle (Fanfan), francois@cerbelle.net
 *
 *  @internal
 *       Created:  20/03/2022
 *      Revision:  none
 * Last modified:  2024-11-23 15:46
 *      Compiler:  gcc
 *  Organization:  Cerbelle.net
 *     Copyright:  Copyright (c) 2024, François Cerbelle
 *
 *  This source code is released for free distribution under the terms of the
 *  GNU General Public License as published by the Free Software Foundation.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <check.h>
#include <stdlib.h>
#include "checktools.inc"

#include "libhttp.h"
#include <stdio.h>                              /* perror */

/** Dummy test to trigger fixtures
 *
 * This test is defined and added to all testcases in order to execute at
 * least one test test in each testcase of the testsuite, trigger the
 * fixtures and have a decent coverage report.
 */
START_TEST(libhttp_test) {
    /* This test is supposed to trigger a SIGABRT(6) and will crash the
     * whole testsuite if not caught or not in a child process */
    forktest_only;

    abort();
}
END_TEST

START_TEST(libhttp_basictest) {
    char* output_str;
    HTTP_t* http;

    http = HTTP_new();

    HTTP_setbody(http,"<HTML></HTML>\r\n");

    if (NULL==(HTTP_addheader(http,"Host","localhost"))) {
        perror("libhttp_basictest HTTP_addheader Host");
        ck_abort();
    }

    if (NULL==(HTTP_addheader(http,"Host","localhost"))) {
        perror("libhttp_basictest HTTP_addheader Host2");
        ck_abort();
    }

    if (NULL==(HTTP_addheader(http,"Content-type","text/html"))) {
        perror("libhttp_basictest HTTP_addheader Host");
        ck_abort();
    }

    output_str=HTTP_buildrequest(HTTPMETHOD_GET,"/v1/api/bdbs",HTTPVERSION_HTTP11);
    printf("%s",output_str);
    free(output_str);

    output_str = HTTP_buildheaders(http);
    printf("%s",output_str);
    free(output_str);

    printf("%s",HTTP_getbody(http));

    HTTP_del(http);

}
END_TEST

/************************************************************************/
/* Begining of test (potentially in child) */
void libhttp_checked_uninitialized_setup() {
    signals_catch();
    forktest_gprofdir();
}

/* End of test (potentially in child) */
void libhttp_checked_uninitialized_teardown() {
    signals_release();
}
/************************************************************************/
void libhttp_unchecked_common_setup() {
    forktest_init();
}
void libhttp_unchecked_common_teardown() {
}
/************************************************************************/
Suite* libhttp_suite() {
    Suite *s;
    TCase *tc;

    s = suite_create("LibHTTP");

    tc = tcase_create("LibHTTPUninitialized");
    tcase_set_tags(tc,"LibHTTPTag LibHTTPTag2");
    /* tcase_set_timeout(tc,5); */ /* seconds */
    tcase_add_checked_fixture(tc, libhttp_checked_uninitialized_setup, libhttp_checked_uninitialized_teardown);
    tcase_add_unchecked_fixture(tc, libhttp_unchecked_common_setup, libhttp_unchecked_common_teardown);
    suite_add_tcase(s, tc);
    tcase_add_test_raise_signal(tc, libhttp_test,6);
    tcase_add_test(tc, libhttp_basictest);

    return s;
}
/* vim: set tw=80: */
